@@ -39,7 +39,7 @@ from ExcelDataDriver.Keywords.CoreExcelKeywords import CoreExcelKeywords
 from ExcelDataDriver.Config.CaptureScreenShotOption import CaptureScreenShotOption
 
 
-__version__ = '1.1.2'
+__version__ = '1.1.4'
 
 
 class ExcelDataDriver:
@@ -559,6 +559,10 @@ class ExcelDataDriver:
         }
         reference_wb.close()
 
+    @keyword
+    def select_reference_data(self, alias_name, data):
+        self.reference_data[alias_name]['selected'] = data
+
     @keyword
     def select_reference_data_based_on_condition(self, alias_name, condition):
         """
